<?php

namespace Drupal\integration_chargebee\Controller;

use Drupal\Core\Controller\ControllerBase;
use ChargeBee\ChargeBee\Environment;
use ChargeBee\ChargeBee\Models\Subscription;
use Drupal\Core\Url;
use Symfony\Component\HttpFoundation\RedirectResponse;
use Drupal\integration_chargebee\Services\ChargebeeService;
use Drupal\Core\Database\Connection;
use Drupal\Core\Messenger\Messenger;
use Drupal\Core\Session\AccountInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Drupal\Core\Logger\LoggerChannelFactoryInterface;

/**
 * An example controller.
 */
class PaymentController extends ControllerBase {

  /**
   * User Account.
   *
   * @var \Drupal\Core\Session\AccountInterface
   */
  protected $account;


  /**
   * Database connection.
   *
   * @var \Drupal\Core\Database\Connection
   */
  protected $connection;

  /**
   * Messenger.
   *
   * @var \Drupal\Core\Messenger\Messenger
   */
  protected $messenger;

  /**
   * integration_chargebee Service.
   *
   * @var \Drupal\integration_chargebee\Services\ChargebeeService
   */
  protected $integration_chargebeeservice;

  /**
   * Logger.
   *
   * @var \Drupal\Core\Logger\LoggerChannelFactoryInterface
   */
  protected $loggerFactory;


  /**
   * Class Constructor.
   *
   * @param \Drupal\Core\Session\AccountInterface $account
   *   Account Interface.
   * @param \Drupal\Core\Database\Connection $connection
   *   Connection.
   * @param \Drupal\Core\Messenger\Messenger $messenger
   *   Messenger.
   * @param \Drupal\integration_chargebee\Services\ChargebeeService $chargebeeService
   *   integration_chargebee Service.
   * @param \Drupal\Core\Logger\LoggerChannelFactoryInterface $logger_factory
   *   Logger.
   */
  public function __construct(
    AccountInterface $account,
    Connection $connection,
    Messenger $messenger,
    ChargebeeService $chargebeeService,
    LoggerChannelFactoryInterface $logger_factory) {
    $this->account = $account;
    $this->connection = $connection;
    $this->messenger = $messenger;
    $this->integration_chargebeeservice = $chargebeeService;
    $this->loggerFactory = $logger_factory->get('integration_chargebee');
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    // Instantiates this form class.
    return new static(
      // Load the service required to construct this class.
      $container->get('current_user'),
      $container->get('database'),
      $container->get('messenger'),
      $container->get('integration_chargebee.integration_chargebee_service'),

      $container->get('logger.factory'),
    );
  }

  /**
   * Returns a payement success data.
   */
  public function success() {
    $config = \Drupal::config('integration_chargebee.settings');
    $site_name = $config->get('integration_chargebee_api_site_name');
        $site_api_key = $config->get('integration_chargebee_api_key');
    Environment::configure("$site_name", "$site_api_key");
    if (isset($_GET['sub_id'])) {
      $sub_id = $_GET['sub_id'];
      try {
        $result = Subscription::retrieve($sub_id);
        if (isset($result)) {
          $subscription = $result->subscription();

          $customer = $result->customer();
          $subscriptions = $this->integration_chargebeeservice->getProtectedValue($subscription, '_data');
          $subscriptions_item = $this->integration_chargebeeservice->getProtectedValue($subscriptions['subscriptionItems'][0], '_data');
          $startedAt = $subscriptions['startedAt'];
          $nextBillingAt = $subscriptions['nextBillingAt'];

          $this->connection->insert('integration_chargebee_subscription')
            ->fields([
              'uid' => $this->account->id(),
              'subscription_id' => $sub_id,
              'plan_id' => $subscriptions_item['itemPriceId'],
              'status' => 'Active',
              'current_term_start' => $startedAt,

              'current_term_end' => $nextBillingAt
            ])
            ->execute();
            $this->connection->insert('integration_chargebee_customer')
            ->fields([
              'uid' => $this->account->id(),
              'customer_id' => $customer->id,

            ])


            ->execute();


        }
      }
      catch (Exception $e) {

      }
    }
    $build = [
      '#markup' => $this->t('Payment Successfully completed.'),
    ];
    $build['#cache']['max-age'] = 0;
    $this->messenger->addMessage('Payment Successfully completed.');



    $url = Url::fromUri('internal:/user/subscriptions');
    $response = new RedirectResponse($url->toString());
    $response->send();

    return $build;
  }



}
