<?php

namespace Drupal\integration_chargebee\Controller;

use Drupal\user\Entity\User;
use Drupal\Core\Controller\ControllerBase;
use ChargeBee\ChargeBee\Environment;
use ChargeBee\ChargeBee\Models\Subscription;
use ChargeBee\ChargeBee\Models\Transaction;
use Drupal\Core\Link;
use Drupal\Core\Url;
use Symfony\Component\HttpFoundation\RedirectResponse;
use Drupal\Core\Render\Markup;
use Drupal\integration_chargebee\Services\ChargebeeService;
use Drupal\Core\Database\Connection;
use Drupal\Core\Messenger\Messenger;
use Drupal\Core\Session\AccountInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Drupal\Core\Logger\LoggerChannelFactoryInterface;
use Drupal\Core\Config\ConfigFactory;
use Drupal\Core\StringTranslation\StringTranslationTrait;
use Drupal\Core\StringTranslation\TranslationInterface;
use Drupal\Core\Entity\EntityTypeManagerInterface;

/**
 * An example controller.
 */
class UserController extends ControllerBase {

  use StringTranslationTrait;

  /**
   * User Account.
   *
   * @var \Drupal\Core\Session\AccountInterface
   */
  protected $account;

 /**
   * Entity manager.
   *
   * @var \Drupal\Core\Entity\EntityTypeManagerInterface
   */
  protected $entityTypeManager;

 /**
   * Database connection.
   *
   * @var \Drupal\Core\Database\Connection
   */
  protected $connection;

  /**
   * Messenger.
   *
   * @var \Drupal\Core\Messenger\Messenger
   */
  protected $messenger;

  /**
   * integration_chargebee Service.
   *
   * @var \Drupal\integration_chargebee\Services\ChargebeeService
   */
  protected $integration_chargebeeservice;

  /**
   * Logger.
   *
   * @var \Drupal\Core\Logger\LoggerChannelFactoryInterface
   */
  protected $loggerFactory;

 /**
   * Config Factory.
   *
   * @var \Drupal\Core\Config\ConfigFactory
   */
  protected $configFactory;

  /**
   * String Translation.
   *
   * @var \Drupal\Core\StringTranslation\TranslationInterface
   */
  protected $stringTranslation;

  /**
   * Class Constructor.
   *
   * @param \Drupal\Core\Session\AccountInterface $account
   *   Account Interface.
   * @param \Drupal\Core\Entity\EntityTypeManagerInterface $entity_type_manager
   *   Entity Type Manager.
   * @param \Drupal\Core\Database\Connection $connection
   *   Connection.
   * @param \Drupal\Core\Messenger\Messenger $messenger
   *   Messenger.
   * @param \Drupal\integration_chargebee\Services\ChargebeeService $ChargebeeService
   *   integration_chargebee Service.
   * @param \Drupal\Core\Logger\LoggerChannelFactoryInterface $loggerFactory
   *   Logger.
   * @param \Drupal\Core\Config\ConfigFactory $configFactory
   *   Config Factory.
   * @param \Drupal\Core\StringTranslation\TranslationInterface $stringTranslation
   *   String Translation.
   */
  public function __construct(
    AccountInterface $account,
    EntityTypeManagerInterface $entity_type_manager,
    Connection $connection,
    Messenger $messenger,
    ChargebeeService $chargebeeService,
    LoggerChannelFactoryInterface $loggerFactory,
    ConfigFactory $configFactory,
    TranslationInterface $stringTranslation) {
    $this->account = $account;
    $this->entityTypeManager = $entity_type_manager;
    $this->connection = $connection;
    $this->messenger = $messenger;
    $this->integration_chargebeeservice = $chargebeeService;
    $this->loggerFactory = $loggerFactory->get('integration_chargebee');
    $this->configFactory = $configFactory;
    $this->stringTranslation = $stringTranslation;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    // Instantiates this form class.
    return new static(
      // Load the service required to construct this class.
      $container->get('current_user'),
      $container->get('entity_type.manager'),
      $container->get('database'),
      $container->get('messenger'),
      $container->get('integration_chargebee.integration_chargebee_service'),
      $container->get('logger.factory'),
      $container->get('config.factory'),
      $container->get('string_translation'),
    );
  }

  /**
   * Returns a payement success data.
   */
  public function subscription() {

    $rows = [];
    global $base_url;
    $config = $this->configFactory->getEditable('integration_chargebee.settings');
    $site_name = $config->get('integration_chargebee_api_site_name');
    $site_api_key = $config->get('integration_chargebee_api_key');
    $site_plan = $config->get('integration_chargebee_api_plan');
    Environment::configure("$site_name", "$site_api_key");
    $user = $this->entityTypeManager->getStorage('user')->load($this->account->id());
    $user_id = $user->id();

    $query = $this->connection->select('integration_chargebee_subscription', 'n');
    $query->fields('n', ['uid', 'subscription_id', 'plan_id', 'status', 'current_term_start', 'current_term_end']);

    $query->condition('n.uid', $user_id);
    $all_doamin = $query->execute()->fetchAll();
    if (!empty($all_doamin)) {
    $link =  Markup::create('<a href="javascript:void(0)" data-cb-type="portal">Manage Subscription</a>');
      foreach ($all_doamin as $kays => $values) {
        if ($values->subscription_id != '') {
          $rows[] = [
            'plan_id' => $values->plan_id,
            'subscription_id' => $values->subscription_id,
            'start_date' => date('m/d/Y', $values->current_term_start),
            'end_date' => date('m/d/Y', $values->current_term_end),
            'status' => $values->status,
            'link' =>  $link
            ,
          ];
        }
      }
    }

    $header = [
      'plan_id' => $this->t('Plan Id'),
      'subscription_id' => $this->t('Subscription Id'),
      'start_date' => $this->t('Start Date'),
      'end_date' => $this->t('End Date'),
      'amount' => $this->t('Amount'),
      'status' => $this->t('Status'),
      'link' => $this->t('link')
    ];

    $build['dblog_table'] = [
      '#type' => 'table',
      '#header' => $header,
      '#rows' => $rows,
      '#attributes' => [
        'id' => 'admin-dblog',
        'class' => [
          'admin-dblog',
        ],
      ],
      '#empty' => $this->t('You have not published any site yet.'),
      '#attached' => [
        'library' => [
          'dblog/drupal.dblog',
        ],
      ],
    ];
    $build['dblog_pager'] = [
      '#type' => 'pager',
    ];
    $build['#cache']['max-age'] = 0;

    return [
      '#type' => '#markup',
      '#markup' => \Drupal::service('renderer')->render($build),
    ];

  }

}
