<?php

namespace Drupal\integration_chargebee\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use ChargeBee\ChargeBee\Environment;
use ChargeBee\ChargeBee\Models\Plan;
use ChargeBee\ChargeBee\Models\Item;
use ChargeBee\ChargeBee\Models\ItemPrice;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Drupal\integration_chargebee\Services\ChargebeeService;

/**
 * Class ChargebeePlanForm.
 *
 * @package Drupal\ChargebeePlanForm\Form
 */
class ChargebeePlanForm extends ConfigFormBase
{

 /**
   * integration_chargebee Service.
   *
   * @var \Drupal\integration_chargebee\Services\ChargebeeService
   */
  protected $integration_chargebeeservice;


  /**
   * Class Constructor.
   *
   * @param \Drupal\integration_chargebee\Services\ChargebeeService $chargebeeService
   *   integration_chargebee Service.
   */

  public function __construct(ChargebeeService $chargebeeService) {
    $this->integration_chargebeeservice = $chargebeeService;
  }


  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    // Instantiates this form class.
    return new static(
      // Load the service required to construct this class.
      $container->get('integration_chargebee.integration_chargebee_service')
     );
  }
    /**
     * {@inheritdoc}
     */
    protected function getEditableConfigNames()
    {
        return [
            'integration_chargebee.plan',
        ];
    }

    /**
     * {@inheritdoc}
     */
    public function getFormId()
    {
        return 'integration_chargebeePlan_form';
    }

    /**
     * {@inheritdoc}
     */
    public function buildForm(array $form, FormStateInterface $form_state)
    {
        $config = \Drupal::config('integration_chargebee.settings');
        $site_name = $config->get('integration_chargebee_api_site_name');
        $site_api_key = $config->get('integration_chargebee_api_key');
        $output = array();
        Environment::configure("$site_name","$site_api_key");
        $plan_list = ItemPrice::all(array(
            "limit" => 20,
            "orderby" => 'desc'
            ));

        $form['plans'] = array(
            '#type' => 'details',
            '#title' => t('Select the plans that you want to replace'),
            '#tree' => false,
          );

        $form['plans']['list'] = $this->_integration_chargebee_create_plans_select_table($plan_list);
        $form['action'] = array(
          '#type' => 'submit',
          '#value' => t('Submit'),

          );

        return $form;
    }

    /**
     * {@inheritdoc}
     */
    public function validateForm(array &$form, FormStateInterface $form_state)
    {
        parent::validateForm($form, $form_state);
    }

    /**
     * {@inheritdoc}
     */
    public function submitForm(array &$form, FormStateInterface $form_state)
    {
        foreach ($form_state->getValue('list') as $key => $value) {
        if ($value > 0) {
          $this->config('integration_chargebee.plan')
            ->set($key, $value)
            ->save();
        }
        }
    }

     /**
    * Create tableselect for plans list.
    */
    public function _integration_chargebee_create_plans_select_table($plans) {
      $config = \Drupal::config('integration_chargebee.plan');
      $select_data = array_keys($config->get());
      $header = array(
       'plan_name' => t('Plan Name'),
       'name' => t('Name'),
       'price' => t('Price'),
       'type' => t('Type'),
       'status' => t('Status'),
     );
     $rows = array();


     foreach ($plans as $plan) {
     $item = $this->integration_chargebeeservice->getProtectedValue($plan->itemPrice(), '_data');
     if ($item['itemType'] == 'plan') {
      $rows[$item['id']] = array(
          'plan_name' => $item['itemId'],
          'name' => $item['name'],
          'price' => $item['currencyCode'].$item['price']/100,
          'type' => $item['itemType'],
          'status' => $item['status'],
        );
      }
      $table = array(
        '#type' => 'tableselect',
        '#header' => $header,
        '#options' => $rows,
        '#default_value' => $select_data,
        '#empty' => t('No plans found'),
      );
    }
     return $table;
   }

}
