<?php

namespace Drupal\integration_chargebee\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

use ChargeBee\ChargeBee\Models\ItemPrice;
use ChargeBee\ChargeBee\Environment;

/**
 * Class SettingsForm.
 *
 * @package Drupal\xai\Form
 */
class SettingsForm extends ConfigFormBase
{

  protected $chargbee_plans = [];

    public function __construct() {
      $config = \Drupal::config('integration_chargebee.plan');
      $this->chargbee_plans = $config->get();
    }

    /**
     * {@inheritdoc}
     */
    protected function getEditableConfigNames()
    {
        return [
            'integration_chargebee.settings',
        ];
    }

    /**
     * {@inheritdoc}
     */
    public function getFormId()
    {
        return 'settings_form';
    }

    /**
     * {@inheritdoc}
     */
    public function buildForm(array $form, FormStateInterface $form_state)
    {

      $config = \Drupal::config('integration_chargebee.settings');
      $site_name = $config->get('integration_chargebee_api_site_name');
      $site_api_key = $config->get('integration_chargebee_api_key');

      Environment::configure("$site_name","$site_api_key");



        $form['api'] = array(
            '#type' => 'details',
            '#title' => t('API Details'),
          );
        $form['api']['integration_chargebee_api_site_name'] = array(
          '#type' => 'textfield',
          '#title' => t('Site name'),
          '#default_value' => $config->get('integration_chargebee_api_site_name'),
          '#disabled' => false,
        );
        $form['api']['integration_chargebee_api_key'] = array(
          '#type' => 'textfield',
          '#title' => t('Key'),
          '#default_value' => $config->get('integration_chargebee_api_key'),
          '#disabled' => false,
        );




        $form['api']['integration_chargebee_api_js_link'] = array(
          '#type' => 'textarea',
          '#title' => t('JS Link'),
          '#default_value' => $config->get('integration_chargebee_api_js_link'),
        );


        if (!empty($this->chargbee_plans)) {
          foreach ( $this->chargbee_plans as $keys =>  $value) {
            $result = ItemPrice::retrieve($value);
            $itemPrice = $result->itemPrice();


            $form['api'][$value] = array(
              '#type' => 'details',
              '#title' => t($itemPrice->itemId),
              '#weight' => 50,
              '#open' => false,
            );

            $form['api'][$value]['integration_chargebee_api_'.$value.'_title'] = array(
              '#type' => 'textfield',
              '#title' => t($itemPrice->name.' Title'),
              '#default_value' => $config->get('integration_chargebee_api_'.$value.'_title') ? $config->get('integration_chargebee_api_'.$value.'_title') : $itemPrice->itemId,
            );

            $form['api'][$value]['integration_chargebee_api_'.$value] = array(
              '#type' => 'textfield',
              '#title' => t($itemPrice->name.' ID'),
              "#disabled" => true,
              '#default_value' => $config->get('integration_chargebee_api_'.$value) ? $config->get('integration_chargebee_api_'.$value) : $itemPrice->id,
            );

            $form['api'][$value]['integration_chargebee_api_'.$value.'_amount'] = array(
              '#type' => 'textfield',
              '#title' => t($itemPrice->name.' Amount'),
              "#disabled" => true,
              '#default_value' => $config->get('integration_chargebee_api_'.$value.'_amount') ? $config->get('integration_chargebee_api_'.$value.'_amount') : $itemPrice->price/100,
            );

            $form['api'][$value]['integration_chargebee_api_'.$value.'_details'] = array(
              '#type' => 'text_format',
              '#format' => 'full_html',
              '#weight' => '20',
              '#title' => t($itemPrice->name.' Details'),
              '#default_value' => $config->get('integration_chargebee_api_'.$value.'_details'),
            );
            $form['api'][$value]['integration_chargebee_api_'.$value.'_status'] = array(
              '#type' => 'checkbox',
              '#title' => t('Enable/Disable.'),
              '#default_value' => $config->get('integration_chargebee_api_'.$value.'_status'),
            );
          }
        }
        $form['api']['integration_chargebee_webhook_hash'] = array(
        '#type' => 'textfield',
        '#title' => t('Webhook hash'),
        '#default_value' => $config->get('integration_chargebee_webhook_hash'),
        );
        $form['service'] = array(
        '#type' => 'details',
        '#title' => t('Test Connection'),
        '#collapsible' => TRUE,
        '#collapsed' => TRUE,
        );
        $form['service']['verify'] = array(
        '#type' => 'submit',
        '#value' => t('Verify Connection'),
        '#submit' => array('integration_chargebee_service_verify_submit'),
        );

        return parent::buildForm($form, $form_state);
    }

    /**
     * {@inheritdoc}
     */
    public function validateForm(array &$form, FormStateInterface $form_state)
    {
        parent::validateForm($form, $form_state);
    }

    /**
     * {@inheritdoc}
     */
    public function submitForm(array &$form, FormStateInterface $form_state)
    {
        parent::submitForm($form, $form_state);

        if (!empty($this->chargbee_plans)) {
          foreach($this->chargbee_plans as $key => $value) {
            $this->config('integration_chargebee.settings')
            ->set('integration_chargebee_api_'.$key, $form_state->getValue('integration_chargebee_api_'.$key))
            ->set('integration_chargebee_api_'.$key.'_amount', $form_state->getValue('integration_chargebee_api_'.$key.'_amount'))
            ->set('integration_chargebee_api_'.$key.'_details', $form_state->getValue('integration_chargebee_api_'.$key.'_details')['value'])
            ->set('integration_chargebee_api_'.$key.'_title', $form_state->getValue('integration_chargebee_api_'.$key.'_title'))
            ->set('integration_chargebee_api_'.$key.'_status', $form_state->getValue('integration_chargebee_api_'.$key.'_status'))

              ->save();
          }
        }

        $this->config('integration_chargebee.settings')
            ->set('integration_chargebee_webhook_hash', $form_state->getValue('integration_chargebee_webhook_hash'))
            ->set('integration_chargebee_api_site_name', $form_state->getValue('integration_chargebee_api_site_name'))
            ->set('integration_chargebee_api_key', $form_state->getValue('integration_chargebee_api_key'))
            ->set('integration_chargebee_api_js_link', $form_state->getValue('integration_chargebee_api_js_link'))

            ->save();
    }
}
