<?php
namespace Drupal\integration_chargebee\Plugin\Block;

use Drupal\Core\Block\BlockBase;
use ChargeBee\ChargeBee\Environment;
use ChargeBee\ChargeBee\Models\Transaction;
use Drupal\integration_chargebee\Services\ChargebeeService;
use Drupal\Core\Plugin\ContainerFactoryPluginInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Provide a block with integration_chargebee Billing history subscription wise.
 * @Block(
 * id = "integration_chargebee_billing_history",
 * admin_label = @Translation("integration_chargebee Billing History")
 * )
 */

class BillingHistoryBlock extends BlockBase implements ContainerFactoryPluginInterface {

  /**
   * integration_chargebee Service.
   *
   * @var \Drupal\integration_chargebee\Services\ChargebeeService
   */
  protected $integration_chargebeeservice;

  /**
   * Class Constructor.
   * @param array $configuration
   * @param string $plugin_id
   * @param mixed $plugin_definition
   * @param \Drupal\integration_chargebee\Services\ChargebeeService $chargebeeService
   *   integration_chargebee Service.
   */
  public function __construct(array $configuration, $plugin_id, $plugin_definition,
    integration_chargebeeService $integration_chargebeeservice
    ) {
      parent::__construct($configuration, $plugin_id, $plugin_definition);
    $this->integration_chargebeeservice = $chargebeeService;

  }


  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    // Instantiates this form class.
    return new static(
      // Load the service required to construct this class.
      $configuration,
      $plugin_id,
      $plugin_definition,
      $container->get('integration_chargebee.integration_chargebee_service')
    );
  }

  /**
     *  {@inheritdoc}
     */
    public function build ()
    {
        $rows = array();

        $config = \Drupal::config('integration_chargebee.settings');

        $site_name = $config->get('integration_chargebee_api_site_name');
        $site_api_key = $config->get('integration_chargebee_api_key');
        Environment::configure("$site_name","$site_api_key");
       if (isset ($_GET['subscriptionId'])) {
        $subscription_id = $_GET['subscriptionId'];
         $all = Transaction::all(array(
            "status[is]" => "success",
            "sortBy[desc]" => "date",
            "limit" => '30',
            "subscriptionId[is]" => $subscription_id
            ));
            foreach($all as $entry){

              $transaction = $entry->transaction();
              $transactions = $this->integration_chargebeeservice->getProtectedValue($transaction, '_data');
              $rows[] = array(
                'id' => $entry->transaction()->id,
                'subscription id' =>  $transactions['subscriptionId'],
                'customer_id' =>  $transactions['customerId'],
                'Occurred_On' => date('m/d/Y',$transactions['date']),
                'type' => $transactions['type'],
                'gateway' => $transactions['gateway'],
                'payment_method' => $transactions['maskedCardNumber'],
                'amount' => '$'.$transactions['amount']/100,
                'status' => $transactions['status'],
              );
            }
          }
           $header = array(
            'id' => t('ID'),
            'subscription' => t('Subscription Id'),
            'customer_id' => t('Customer Id'),
            'Occurred_On' => t('Occurred On'),
            'type' => t('Type'),
            'gateway' => t('Gateway'),
            'payment_method' => t('Payment Method'),
            'amount' => t('Amount'),
            'status' => t('Status'),
          );

          $build['dblog_table'] = [
            '#type' => 'table',
            '#header' => $header,
            '#rows' => $rows,
            '#attributes' => [
              'id' => 'admin-dblog',
              'class' => [
                'admin-dblog',
              ],
            ],
            '#empty' => $this->t('You have not published any site yet.'),
            '#attached' => [
              'library' => [
                'dblog/drupal.dblog',
              ],
            ],
          ];

          $build['#cache']['max-age'] = 0;
          return $build;

    }
}
